==> ejc-probudget-impl-3.0.0-20210910.024505-13-sources.jar: com/ejianc/business/budget/bean/BudgetDetailEntity.java <==
package com.ejianc.business.budget.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 预算管理明细
 *
 * @author generator
 *
 */
 @TableName("ejc_probudget_budget_detail")
public class BudgetDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="budget_id")
    private Long budgetId; // 主表ID
    @TableField(value="change_id")
    private Long changeId; // 变更主键
    @TableField(value="src_bid")
    private Long srcBid; // 变更子表主键
    @TableField(value="tree_index")
    private String treeIndex; // 序号
    @TableField(value="building_no")
    private String buildingNo; // 楼号
    @TableField(value="build_content")
    private String buildContent; // 施工内容
    @TableField(value="craft")
    private String craft; // 工艺
    @TableField(value="stages")
    private String stages; // 工序
    @TableField(value="budget_num")
    private java.math.BigDecimal budgetNum; // 收入预算工程量
    @TableField(value="budget_unit")
    private String budgetUnit; // 收入预算单位
    @TableField(value="budget_price")
    private java.math.BigDecimal budgetPrice; // 收入预算综合单价
    @TableField(value="budget_money")
    private java.math.BigDecimal budgetMoney; // 收入预算合价
    @TableField(value="cost_num")
    private java.math.BigDecimal costNum; // 劳务预算工程量
    @TableField(value="cost_price")
    private java.math.BigDecimal costPrice; // 劳务预算综合单价
    @TableField(value="cost_money")
    private java.math.BigDecimal costMoney; // 劳务预算合价
    @TableField(value="material_id")
    private Long materialId; // 物料ID
    @TableField(value="material_name")
    private String materialName; // 物料名称
    @TableField(value="material_weight_scale")
    private java.math.BigDecimal materialWeightScale; // 材料预算产值权重
    @TableField(value="material_used_scale")
    private java.math.BigDecimal materialUsedScale; // 材料预算材料使用率
    @TableField(value="material_used_num")
    private java.math.BigDecimal materialUsedNum; // 材料预算耗量
    @TableField(value="material_plan_num")
    private java.math.BigDecimal materialPlanNum; // 材料预算计划用量
    @TableField(value="material_price")
    private java.math.BigDecimal materialPrice; // 材料预算综合单价
    @TableField(value="material_unit")
    private String materialUnit; // 材料预算单位
    @TableField(value="material_money")
    private String materialMoney; // 材料预算合价
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="parent_id")
    private Long parentId; // 父ID
    @TableField(value="leaf_flag")
    private Integer leafFlag; // 是否末级
    @TableField(value="level_no")
    private Integer levelNo; // 级次
    @TableField(value="change_type")
    private Integer changeType; // 变更类型




    /**
     * 主表ID
     */
    public Long getBudgetId() {
        return budgetId;
    }

    /**
     * 主表ID
     */
    public void setBudgetId(Long budgetId) {
        this.budgetId = budgetId;
    }
    /**
     * 变更主键
     */
    public Long getChangeId() {
        return changeId;
    }

    /**
     * 变更主键
     */
    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更子表主键
     */
    public Long getSrcBid() {
        return srcBid;
    }

    /**
     * 变更子表主键
     */
    public void setSrcBid(Long srcBid) {
        this.srcBid = srcBid;
    }
    /**
     * 序号
     */
    public String getTreeIndex() {
        return treeIndex;
    }

    /**
     * 序号
     */
    public void setTreeIndex(String treeIndex) {
        this.treeIndex = treeIndex;
    }
    /**
     * 楼号
     */
    public String getBuildingNo() {
        return buildingNo;
    }

    /**
     * 楼号
     */
    public void setBuildingNo(String buildingNo) {
        this.buildingNo = buildingNo;
    }
    /**
     * 施工内容
     */
    public String getBuildContent() {
        return buildContent;
    }

    /**
     * 施工内容
     */
    public void setBuildContent(String buildContent) {
        this.buildContent = buildContent;
    }
    /**
     * 工艺
     */
    public String getCraft() {
        return craft;
    }

    /**
     * 工艺
     */
    public void setCraft(String craft) {
        this.craft = craft;
    }
    /**
     * 工序
     */
    public String getStages() {
        return stages;
    }

    /**
     * 工序
     */
    public void setStages(String stages) {
        this.stages = stages;
    }
    /**
     * 收入预算工程量
     */
    public java.math.BigDecimal getBudgetNum() {
        return budgetNum;
    }

    /**
     * 收入预算工程量
     */
    public void setBudgetNum(java.math.BigDecimal budgetNum) {
        this.budgetNum = budgetNum;
    }
    /**
     * 收入预算单位
     */
    public String getBudgetUnit() {
        return budgetUnit;
    }

    /**
     * 收入预算单位
     */
    public void setBudgetUnit(String budgetUnit) {
        this.budgetUnit = budgetUnit;
    }
    /**
     * 收入预算综合单价
     */
    public java.math.BigDecimal getBudgetPrice() {
        return budgetPrice;
    }

    /**
     * 收入预算综合单价
     */
    public void setBudgetPrice(java.math.BigDecimal budgetPrice) {
        this.budgetPrice = budgetPrice;
    }
    /**
     * 收入预算合价
     */
    public java.math.BigDecimal getBudgetMoney() {
        return budgetMoney;
    }

    /**
     * 收入预算合价
     */
    public void setBudgetMoney(java.math.BigDecimal budgetMoney) {
        this.budgetMoney = budgetMoney;
    }
    /**
     * 劳务预算工程量
     */
    public java.math.BigDecimal getCostNum() {
        return costNum;
    }

    /**
     * 劳务预算工程量
     */
    public void setCostNum(java.math.BigDecimal costNum) {
        this.costNum = costNum;
    }
    /**
     * 劳务预算综合单价
     */
    public java.math.BigDecimal getCostPrice() {
        return costPrice;
    }

    /**
     * 劳务预算综合单价
     */
    public void setCostPrice(java.math.BigDecimal costPrice) {
        this.costPrice = costPrice;
    }
    /**
     * 劳务预算合价
     */
    public java.math.BigDecimal getCostMoney() {
        return costMoney;
    }

    /**
     * 劳务预算合价
     */
    public void setCostMoney(java.math.BigDecimal costMoney) {
        this.costMoney = costMoney;
    }
    /**
     * 物料ID
     */
    public Long getMaterialId() {
        return materialId;
    }

    /**
     * 物料ID
     */
    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物料名称
     */
    public String getMaterialName() {
        return materialName;
    }

    /**
     * 物料名称
     */
    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    /**
     * 材料预算产值权重
     */
    public java.math.BigDecimal getMaterialWeightScale() {
        return materialWeightScale;
    }

    /**
     * 材料预算产值权重
     */
    public void setMaterialWeightScale(java.math.BigDecimal materialWeightScale) {
        this.materialWeightScale = materialWeightScale;
    }
    /**
     * 材料预算材料使用率
     */
    public java.math.BigDecimal getMaterialUsedScale() {
        return materialUsedScale;
    }

    /**
     * 材料预算材料使用率
     */
    public void setMaterialUsedScale(java.math.BigDecimal materialUsedScale) {
        this.materialUsedScale = materialUsedScale;
    }
    /**
     * 材料预算耗量
     */
    public java.math.BigDecimal getMaterialUsedNum() {
        return materialUsedNum;
    }

    /**
     * 材料预算耗量
     */
    public void setMaterialUsedNum(java.math.BigDecimal materialUsedNum) {
        this.materialUsedNum = materialUsedNum;
    }
    /**
     * 材料预算计划用量
     */
    public java.math.BigDecimal getMaterialPlanNum() {
        return materialPlanNum;
    }

    /**
     * 材料预算计划用量
     */
    public void setMaterialPlanNum(java.math.BigDecimal materialPlanNum) {
        this.materialPlanNum = materialPlanNum;
    }
    /**
     * 材料预算综合单价
     */
    public java.math.BigDecimal getMaterialPrice() {
        return materialPrice;
    }

    /**
     * 材料预算综合单价
     */
    public void setMaterialPrice(java.math.BigDecimal materialPrice) {
        this.materialPrice = materialPrice;
    }
    /**
     * 材料预算单位
     */
    public String getMaterialUnit() {
        return materialUnit;
    }

    /**
     * 材料预算单位
     */
    public void setMaterialUnit(String materialUnit) {
        this.materialUnit = materialUnit;
    }
    /**
     * 材料预算合价
     */
    public String getMaterialMoney() {
        return materialMoney;
    }

    /**
     * 材料预算合价
     */
    public void setMaterialMoney(String materialMoney) {
        this.materialMoney = materialMoney;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 父ID
     */
    public Long getParentId() {
        return parentId;
    }

    /**
     * 父ID
     */
    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }
    /**
     * 是否末级
     */
    public Integer getLeafFlag() {
        return leafFlag;
    }

    /**
     * 是否末级
     */
    public void setLeafFlag(Integer leafFlag) {
        this.leafFlag = leafFlag;
    }
    /**
     * 级次
     */
    public Integer getLevelNo() {
        return levelNo;
    }

    /**
     * 级次
     */
    public void setLevelNo(Integer levelNo) {
        this.levelNo = levelNo;
    }
    /**
     * 变更类型
     */
    public Integer getChangeType() {
        return changeType;
    }

    /**
     * 变更类型
     */
    public void setChangeType(Integer changeType) {
        this.changeType = changeType;
    }

}

==> ejc-probudget-impl-3.0.0-20210913.101251-20-sources.jar: com/ejianc/business/budget/bean/BudgetDetailEntity.java <==
package com.ejianc.business.budget.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 预算管理明细
 *
 * @author generator
 *
 */
 @TableName("ejc_probudget_budget_detail")
public class BudgetDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="budget_id")
    private Long budgetId; // 主表ID
    @TableField(value="change_id")
    private Long changeId; // 变更主键
    @TableField(value="src_bid")
    private Long srcBid; // 变更子表主键
    @TableField(value="tree_index")
    private String treeIndex; // 序号
    @TableField(value="building_no")
    private String buildingNo; // 楼号
    @TableField(value="build_content")
    private String buildContent; // 施工内容
    @TableField(value="craft")
    private String craft; // 工艺
    @TableField(value="stages")
    private String stages; // 工序
    @TableField(value="budget_num")
    private java.math.BigDecimal budgetNum; // 收入预算工程量
    @TableField(value="budget_unit")
    private String budgetUnit; // 收入预算单位
    @TableField(value="budget_price")
    private java.math.BigDecimal budgetPrice; // 收入预算综合单价
    @TableField(value="budget_money")
    private java.math.BigDecimal budgetMoney; // 收入预算合价
    @TableField(value="cost_num")
    private java.math.BigDecimal costNum; // 劳务预算工程量
    @TableField(value="cost_price")
    private java.math.BigDecimal costPrice; // 劳务预算综合单价
    @TableField(value="cost_money")
    private java.math.BigDecimal costMoney; // 劳务预算合价
    @TableField(value="material_id")
    private Long materialId; // 物料ID
    @TableField(value="material_name")
    private String materialName; // 物料名称
    @TableField(value="material_weight_scale")
    private java.math.BigDecimal materialWeightScale; // 材料预算产值权重
    @TableField(value="material_used_scale")
    private java.math.BigDecimal materialUsedScale; // 材料预算材料使用率
    @TableField(value="material_used_num")
    private java.math.BigDecimal materialUsedNum; // 材料预算耗量
    @TableField(value="material_plan_num")
    private java.math.BigDecimal materialPlanNum; // 材料预算计划用量
    @TableField(value="material_price")
    private java.math.BigDecimal materialPrice; // 材料预算综合单价
    @TableField(value="material_unit")
    private String materialUnit; // 材料预算单位
    @TableField(value="material_money")
    private String materialMoney; // 材料预算合价
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="parent_id")
    private Long parentId; // 父ID
    @TableField(value="leaf_flag")
    private Boolean leafFlag; // 是否末级
    @TableField(value="level_no")
    private Integer levelNo; // 级次
    @TableField(value="change_type")
    private Integer changeType; // 变更类型

    @TableField(exist = false)
    private String tid;
    @TableField(exist = false)
    private String tpid;


    /**
     * 主表ID
     */
    public Long getBudgetId() {
        return budgetId;
    }

    /**
     * 主表ID
     */
    public void setBudgetId(Long budgetId) {
        this.budgetId = budgetId;
    }
    /**
     * 变更主键
     */
    public Long getChangeId() {
        return changeId;
    }

    /**
     * 变更主键
     */
    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更子表主键
     */
    public Long getSrcBid() {
        return srcBid;
    }

    /**
     * 变更子表主键
     */
    public void setSrcBid(Long srcBid) {
        this.srcBid = srcBid;
    }
    /**
     * 序号
     */
    public String getTreeIndex() {
        return treeIndex;
    }

    /**
     * 序号
     */
    public void setTreeIndex(String treeIndex) {
        this.treeIndex = treeIndex;
    }
    /**
     * 楼号
     */
    public String getBuildingNo() {
        return buildingNo;
    }

    /**
     * 楼号
     */
    public void setBuildingNo(String buildingNo) {
        this.buildingNo = buildingNo;
    }
    /**
     * 施工内容
     */
    public String getBuildContent() {
        return buildContent;
    }

    /**
     * 施工内容
     */
    public void setBuildContent(String buildContent) {
        this.buildContent = buildContent;
    }
    /**
     * 工艺
     */
    public String getCraft() {
        return craft;
    }

    /**
     * 工艺
     */
    public void setCraft(String craft) {
        this.craft = craft;
    }
    /**
     * 工序
     */
    public String getStages() {
        return stages;
    }

    /**
     * 工序
     */
    public void setStages(String stages) {
        this.stages = stages;
    }
    /**
     * 收入预算工程量
     */
    public java.math.BigDecimal getBudgetNum() {
        return budgetNum;
    }

    /**
     * 收入预算工程量
     */
    public void setBudgetNum(java.math.BigDecimal budgetNum) {
        this.budgetNum = budgetNum;
    }
    /**
     * 收入预算单位
     */
    public String getBudgetUnit() {
        return budgetUnit;
    }

    /**
     * 收入预算单位
     */
    public void setBudgetUnit(String budgetUnit) {
        this.budgetUnit = budgetUnit;
    }
    /**
     * 收入预算综合单价
     */
    public java.math.BigDecimal getBudgetPrice() {
        return budgetPrice;
    }

    /**
     * 收入预算综合单价
     */
    public void setBudgetPrice(java.math.BigDecimal budgetPrice) {
        this.budgetPrice = budgetPrice;
    }
    /**
     * 收入预算合价
     */
    public java.math.BigDecimal getBudgetMoney() {
        return budgetMoney;
    }

    /**
     * 收入预算合价
     */
    public void setBudgetMoney(java.math.BigDecimal budgetMoney) {
        this.budgetMoney = budgetMoney;
    }
    /**
     * 劳务预算工程量
     */
    public java.math.BigDecimal getCostNum() {
        return costNum;
    }

    /**
     * 劳务预算工程量
     */
    public void setCostNum(java.math.BigDecimal costNum) {
        this.costNum = costNum;
    }
    /**
     * 劳务预算综合单价
     */
    public java.math.BigDecimal getCostPrice() {
        return costPrice;
    }

    /**
     * 劳务预算综合单价
     */
    public void setCostPrice(java.math.BigDecimal costPrice) {
        this.costPrice = costPrice;
    }
    /**
     * 劳务预算合价
     */
    public java.math.BigDecimal getCostMoney() {
        return costMoney;
    }

    /**
     * 劳务预算合价
     */
    public void setCostMoney(java.math.BigDecimal costMoney) {
        this.costMoney = costMoney;
    }
    /**
     * 物料ID
     */
    public Long getMaterialId() {
        return materialId;
    }

    /**
     * 物料ID
     */
    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物料名称
     */
    public String getMaterialName() {
        return materialName;
    }

    /**
     * 物料名称
     */
    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    /**
     * 材料预算产值权重
     */
    public java.math.BigDecimal getMaterialWeightScale() {
        return materialWeightScale;
    }

    /**
     * 材料预算产值权重
     */
    public void setMaterialWeightScale(java.math.BigDecimal materialWeightScale) {
        this.materialWeightScale = materialWeightScale;
    }
    /**
     * 材料预算材料使用率
     */
    public java.math.BigDecimal getMaterialUsedScale() {
        return materialUsedScale;
    }

    /**
     * 材料预算材料使用率
     */
    public void setMaterialUsedScale(java.math.BigDecimal materialUsedScale) {
        this.materialUsedScale = materialUsedScale;
    }
    /**
     * 材料预算耗量
     */
    public java.math.BigDecimal getMaterialUsedNum() {
        return materialUsedNum;
    }

    /**
     * 材料预算耗量
     */
    public void setMaterialUsedNum(java.math.BigDecimal materialUsedNum) {
        this.materialUsedNum = materialUsedNum;
    }
    /**
     * 材料预算计划用量
     */
    public java.math.BigDecimal getMaterialPlanNum() {
        return materialPlanNum;
    }

    /**
     * 材料预算计划用量
     */
    public void setMaterialPlanNum(java.math.BigDecimal materialPlanNum) {
        this.materialPlanNum = materialPlanNum;
    }
    /**
     * 材料预算综合单价
     */
    public java.math.BigDecimal getMaterialPrice() {
        return materialPrice;
    }

    /**
     * 材料预算综合单价
     */
    public void setMaterialPrice(java.math.BigDecimal materialPrice) {
        this.materialPrice = materialPrice;
    }
    /**
     * 材料预算单位
     */
    public String getMaterialUnit() {
        return materialUnit;
    }

    /**
     * 材料预算单位
     */
    public void setMaterialUnit(String materialUnit) {
        this.materialUnit = materialUnit;
    }
    /**
     * 材料预算合价
     */
    public String getMaterialMoney() {
        return materialMoney;
    }

    /**
     * 材料预算合价
     */
    public void setMaterialMoney(String materialMoney) {
        this.materialMoney = materialMoney;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 父ID
     */
    public Long getParentId() {
        return parentId;
    }

    /**
     * 父ID
     */
    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }
    /**
     * 是否末级
     */
    public Boolean getLeafFlag() {
        return leafFlag;
    }

    /**
     * 是否末级
     */
    public void setLeafFlag(Boolean leafFlag) {
        this.leafFlag = leafFlag;
    }
    /**
     * 级次
     */
    public Integer getLevelNo() {
        return levelNo;
    }

    /**
     * 级次
     */
    public void setLevelNo(Integer levelNo) {
        this.levelNo = levelNo;
    }
    /**
     * 变更类型
     */
    public Integer getChangeType() {
        return changeType;
    }

    /**
     * 变更类型
     */
    public void setChangeType(Integer changeType) {
        this.changeType = changeType;
    }


    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }

}
